@@ -24,6 +24,7 @@ type UserConfig struct {
 	// If true, don't display introductory popups upon opening Lazygit.
 	DisableStartupPopups bool `yaml:"disableStartupPopups"`
 	// User-configured commands that can be invoked from within Lazygit
+	// See https://github.com/jesseduffield/lazygit/blob/master/docs/Custom_Command_Keybindings.md
 	CustomCommands []CustomCommand `yaml:"customCommands" jsonschema:"uniqueItems=true"`
 	// See https://github.com/jesseduffield/lazygit/blob/master/docs/Config.md#custom-pull-request-urls
 	Services map[string]string `yaml:"services"`
@@ -53,9 +54,12 @@ type GuiConfig struct {
 	AuthorColors map[string]string `yaml:"authorColors"`
 	// See https://github.com/jesseduffield/lazygit/blob/master/docs/Config.md#custom-branch-color
 	// Deprecated: use branchColorPatterns instead
-	BranchColors map[string]string `yaml:"branchColors"`
+	BranchColors map[string]string `yaml:"branchColors" jsonschema:"deprecated"`
 	// See https://github.com/jesseduffield/lazygit/blob/master/docs/Config.md#custom-branch-color
 	BranchColorPatterns map[string]string `yaml:"branchColorPatterns"`
+	// Custom icons for filenames and file extensions
+	// See https://github.com/jesseduffield/lazygit/blob/master/docs/Config.md#custom-files-icon--color
+	CustomIcons CustomIconsConfig `yaml:"customIcons"`
 	// The number of lines you scroll by when scrolling the main window
 	ScrollHeight int `yaml:"scrollHeight" jsonschema:"minimum=1"`
 	// If true, allow scrolling past the bottom of the content in the main window
@@ -130,7 +134,7 @@ type GuiConfig struct {
 	// If true, show jump-to-window keybindings in window titles.
 	ShowPanelJumps bool `yaml:"showPanelJumps"`
 	// Deprecated: use nerdFontsVersion instead
-	ShowIcons bool `yaml:"showIcons"`
+	ShowIcons bool `yaml:"showIcons" jsonschema:"deprecated"`
 	// Nerd fonts version to use.
 	// One of: '2' | '3' | empty string (default)
 	// If empty, do not show icons.
@@ -251,8 +255,8 @@ type GitConfig struct {
 	BranchLogCmd string `yaml:"branchLogCmd"`
 	// Command used to display git log of all branches in the main window.
 	// Deprecated: Use `allBranchesLogCmds` instead.
-	AllBranchesLogCmd string `yaml:"allBranchesLogCmd"`
-	// Commands used to display git log of all branches in the main window, they will be cycled in order of appearance
+	AllBranchesLogCmd string `yaml:"allBranchesLogCmd" jsonschema:"deprecated"`
+	// Commands used to display git log of all branches in the main window, they will be cycled in order of appearance (array of strings)
 	AllBranchesLogCmds []string `yaml:"allBranchesLogCmds"`
 	// If true, do not spawn a separate process when using GPG
 	OverrideGpg bool `yaml:"overrideGpg"`
@@ -379,6 +383,8 @@ type KeybindingUniversalConfig struct {
 	ScrollRight                       string   `yaml:"scrollRight"`
 	GotoTop                           string   `yaml:"gotoTop"`
 	GotoBottom                        string   `yaml:"gotoBottom"`
+	GotoTopAlt                        string   `yaml:"gotoTop-alt"`
+	GotoBottomAlt                     string   `yaml:"gotoBottom-alt"`
 	ToggleRangeSelect                 string   `yaml:"toggleRangeSelect"`
 	RangeSelectDown                   string   `yaml:"rangeSelectDown"`
 	RangeSelectUp                     string   `yaml:"rangeSelectUp"`
@@ -510,6 +516,7 @@ type KeybindingCommitsConfig struct {
 	OpenInBrowser                  string `yaml:"openInBrowser"`
 	ViewBisectOptions              string `yaml:"viewBisectOptions"`
 	StartInteractiveRebase         string `yaml:"startInteractiveRebase"`
+	SelectCommitsOfCurrentBranch   string `yaml:"selectCommitsOfCurrentBranch"`
 }
 
 type KeybindingAmendAttributeConfig struct {
@@ -566,7 +573,7 @@ type OSConfig struct {
 
 	// A built-in preset that sets all of the above settings. Supported presets
 	// are defined in the getPreset function in editor_presets.go.
-	EditPreset string `yaml:"editPreset,omitempty" jsonschema:"example=vim,example=nvim,example=emacs,example=nano,example=vscode,example=sublime,example=kakoune,example=helix,example=xcode,example=zed"`
+	EditPreset string `yaml:"editPreset,omitempty" jsonschema:"example=vim,example=nvim,example=emacs,example=nano,example=vscode,example=sublime,example=kakoune,example=helix,example=xcode,example=zed,example=acme"`
 
 	// Command for opening a file, as if the file is double-clicked. Should
 	// contain "{{filename}}", but doesn't support "{{line}}".
@@ -575,6 +582,18 @@ type OSConfig struct {
 	// Command for opening a link. Should contain "{{link}}".
 	OpenLink string `yaml:"openLink,omitempty"`
 
+	// CopyToClipboardCmd is the command for copying to clipboard.
+	// See https://github.com/jesseduffield/lazygit/blob/master/docs/Config.md#custom-command-for-copying-to-and-pasting-from-clipboard
+	CopyToClipboardCmd string `yaml:"copyToClipboardCmd,omitempty"`
+
+	// ReadFromClipboardCmd is the command for reading the clipboard.
+	// See https://github.com/jesseduffield/lazygit/blob/master/docs/Config.md#custom-command-for-copying-to-and-pasting-from-clipboard
+	ReadFromClipboardCmd string `yaml:"readFromClipboardCmd,omitempty"`
+
+	// A shell startup file containing shell aliases or shell functions. This will be sourced before running any shell commands, so that shell functions are available in the `:` command prompt or even in custom commands.
+	// See https://github.com/jesseduffield/lazygit/blob/master/docs/Config.md#using-aliases-or-functions-in-shell-commands
+	ShellFunctionsFile string `yaml:"shellFunctionsFile"`
+
 	// --------
 
 	// The following configs are all deprecated and kept for backward
@@ -584,27 +603,19 @@ type OSConfig struct {
 	// Deprecated: use Edit instead. Note that semantics are different:
 	// EditCommand is just the command itself, whereas Edit contains a
 	// "{{filename}}" variable.
-	EditCommand string `yaml:"editCommand,omitempty"`
+	EditCommand string `yaml:"editCommand,omitempty" jsonschema:"deprecated"`
 
 	// EditCommandTemplate is the command template for editing a file
 	// Deprecated: use EditAtLine instead.
-	EditCommandTemplate string `yaml:"editCommandTemplate,omitempty"`
+	EditCommandTemplate string `yaml:"editCommandTemplate,omitempty" jsonschema:"deprecated"`
 
 	// OpenCommand is the command for opening a file
 	// Deprecated: use Open instead.
-	OpenCommand string `yaml:"openCommand,omitempty"`
+	OpenCommand string `yaml:"openCommand,omitempty" jsonschema:"deprecated"`
 
 	// OpenLinkCommand is the command for opening a link
 	// Deprecated: use OpenLink instead.
-	OpenLinkCommand string `yaml:"openLinkCommand,omitempty"`
-
-	// CopyToClipboardCmd is the command for copying to clipboard.
-	// See https://github.com/jesseduffield/lazygit/blob/master/docs/Config.md#custom-command-for-copying-to-and-pasting-from-clipboard
-	CopyToClipboardCmd string `yaml:"copyToClipboardCmd,omitempty"`
-
-	// ReadFromClipboardCmd is the command for reading the clipboard.
-	// See https://github.com/jesseduffield/lazygit/blob/master/docs/Config.md#custom-command-for-copying-to-and-pasting-from-clipboard
-	ReadFromClipboardCmd string `yaml:"readFromClipboardCmd,omitempty"`
+	OpenLinkCommand string `yaml:"openLinkCommand,omitempty" jsonschema:"deprecated"`
 }
 
 type CustomCommandAfterHook struct {
@@ -704,6 +715,18 @@ type CustomCommandMenuOption struct {
 	Value string `yaml:"value" jsonschema:"example=feature,minLength=1"`
 }
 
+type CustomIconsConfig struct {
+	// Map of filenames to icon properties (icon and color)
+	Filenames map[string]IconProperties `yaml:"filenames"`
+	// Map of file extensions (including the dot) to icon properties (icon and color)
+	Extensions map[string]IconProperties `yaml:"extensions"`
+}
+
+type IconProperties struct {
+	Icon  string `yaml:"icon"`
+	Color string `yaml:"color"`
+}
+
 func GetDefaultConfig() *UserConfig {
 	return &UserConfig{
 		Gui: GuiConfig{
@@ -841,6 +864,8 @@ func GetDefaultConfig() *UserConfig {
 				ScrollRight:                       "L",
 				GotoTop:                           "<",
 				GotoBottom:                        ">",
+				GotoTopAlt:                        "<home>",
+				GotoBottomAlt:                     "<end>",
 				ToggleRangeSelect:                 "v",
 				RangeSelectDown:                   "<s-down>",
 				RangeSelectUp:                     "<s-up>",
@@ -967,6 +992,7 @@ func GetDefaultConfig() *UserConfig {
 				OpenInBrowser:                  "o",
 				ViewBisectOptions:              "b",
 				StartInteractiveRebase:         "i",
+				SelectCommitsOfCurrentBranch:   "*",
 			},
 			AmendAttribute: KeybindingAmendAttributeConfig{
 				ResetAuthor: "a",
