@@ -122,6 +122,16 @@ func (self *PatchExplorerController) GetKeybindings(opts types.KeybindingsOpts)
 			Description: self.c.Tr.GotoBottom,
 			Handler:     self.withRenderAndFocus(self.HandleGotoBottom),
 		},
+		{
+			Tag:     "navigation",
+			Key:     opts.GetKey(opts.Config.Universal.GotoTopAlt),
+			Handler: self.withRenderAndFocus(self.HandleGotoTop),
+		},
+		{
+			Tag:     "navigation",
+			Key:     opts.GetKey(opts.Config.Universal.GotoBottomAlt),
+			Handler: self.withRenderAndFocus(self.HandleGotoBottom),
+		},
 		{
 			Tag:     "navigation",
 			Key:     opts.GetKey(opts.Config.Universal.ScrollLeft),
