@@ -331,6 +331,8 @@ func (gui *Gui) onNewRepo(startArgs appTypes.StartArgs, contextKey types.Context
 
 	gui.g.SetFocusHandler(func(Focused bool) error {
 		if Focused {
+			gui.git.Config.DropConfigCache()
+
 			oldConfig := gui.Config.GetUserConfig()
 			reloadErr, didChange := gui.Config.ReloadChangedUserConfigFiles()
 			if didChange && reloadErr == nil {
@@ -392,7 +394,7 @@ func (gui *Gui) onNewRepo(startArgs appTypes.StartArgs, contextKey types.Context
 		}
 	}
 
-	gui.c.Context().Push(contextToPush)
+	gui.c.Context().Push(contextToPush, types.OnFocusOpts{})
 
 	return nil
 }
@@ -424,6 +426,15 @@ func (gui *Gui) onUserConfigLoaded() error {
 	userConfig := gui.Config.GetUserConfig()
 	gui.Common.SetUserConfig(userConfig)
 
+	if gui.previousLanguageConfig != userConfig.Gui.Language {
+		tr, err := i18n.NewTranslationSetFromConfig(gui.Log, userConfig.Gui.Language)
+		if err != nil {
+			return err
+		}
+		gui.c.Tr = tr
+		gui.previousLanguageConfig = userConfig.Gui.Language
+	}
+
 	gui.setColorScheme()
 	gui.configureViewProperties()
 
@@ -435,15 +446,6 @@ func (gui *Gui) onUserConfigLoaded() error {
 
 	gui.g.Mouse = userConfig.Gui.MouseEvents
 
-	if gui.previousLanguageConfig != userConfig.Gui.Language {
-		tr, err := i18n.NewTranslationSetFromConfig(gui.Log, userConfig.Gui.Language)
-		if err != nil {
-			return err
-		}
-		gui.c.Tr = tr
-		gui.previousLanguageConfig = userConfig.Gui.Language
-	}
-
 	// originally we could only hide the command log permanently via the config
 	// but now we do it via state. So we need to still support the config for the
 	// sake of backwards compatibility. We're making use of short circuiting here
