@@ -6,6 +6,7 @@ import (
 	"github.com/gookit/color"
 	"github.com/jesseduffield/lazygit/pkg/commands/models"
 	"github.com/jesseduffield/lazygit/pkg/commands/patch"
+	"github.com/jesseduffield/lazygit/pkg/config"
 	"github.com/jesseduffield/lazygit/pkg/gui/filetree"
 	"github.com/jesseduffield/lazygit/pkg/gui/presentation/icons"
 	"github.com/jesseduffield/lazygit/pkg/gui/style"
@@ -22,12 +23,14 @@ func RenderFileTree(
 	tree filetree.IFileTree,
 	submoduleConfigs []*models.SubmoduleConfig,
 	showFileIcons bool,
+	showNumstat bool,
+	customIconsConfig *config.CustomIconsConfig,
 ) []string {
 	collapsedPaths := tree.CollapsedPaths()
 	return renderAux(tree.GetRoot().Raw(), collapsedPaths, -1, -1, func(node *filetree.Node[models.File], treeDepth int, visualDepth int, isCollapsed bool) string {
 		fileNode := filetree.NewFileNode(node)
 
-		return getFileLine(isCollapsed, fileNode.GetHasUnstagedChanges(), fileNode.GetHasStagedChanges(), treeDepth, visualDepth, showFileIcons, submoduleConfigs, node)
+		return getFileLine(isCollapsed, fileNode.GetHasUnstagedChanges(), fileNode.GetHasStagedChanges(), treeDepth, visualDepth, showNumstat, showFileIcons, submoduleConfigs, node, customIconsConfig)
 	})
 }
 
@@ -35,12 +38,13 @@ func RenderCommitFileTree(
 	tree *filetree.CommitFileTreeViewModel,
 	patchBuilder *patch.PatchBuilder,
 	showFileIcons bool,
+	customIconsConfig *config.CustomIconsConfig,
 ) []string {
 	collapsedPaths := tree.CollapsedPaths()
 	return renderAux(tree.GetRoot().Raw(), collapsedPaths, -1, -1, func(node *filetree.Node[models.CommitFile], treeDepth int, visualDepth int, isCollapsed bool) string {
 		status := commitFilePatchStatus(node, tree, patchBuilder)
 
-		return getCommitFileLine(isCollapsed, treeDepth, visualDepth, node, status, showFileIcons)
+		return getCommitFileLine(isCollapsed, treeDepth, visualDepth, node, status, showFileIcons, customIconsConfig)
 	})
 }
 
@@ -51,11 +55,11 @@ func commitFilePatchStatus(node *filetree.Node[models.CommitFile], tree *filetre
 	// be whatever status it is, but if it's a non-leaf it will determine its status
 	// based on the leaves of that subtree
 	if node.EveryFile(func(file *models.CommitFile) bool {
-		return patchBuilder.GetFileStatus(file.Name, tree.GetRef().RefName()) == patch.WHOLE
+		return patchBuilder.GetFileStatus(file.Path, tree.GetRef().RefName()) == patch.WHOLE
 	}) {
 		return patch.WHOLE
 	} else if node.EveryFile(func(file *models.CommitFile) bool {
-		return patchBuilder.GetFileStatus(file.Name, tree.GetRef().RefName()) == patch.UNSELECTED
+		return patchBuilder.GetFileStatus(file.Path, tree.GetRef().RefName()) == patch.UNSELECTED
 	}) {
 		return patch.UNSELECTED
 	} else {
@@ -90,11 +94,11 @@ func renderAux[T any](
 
 	arr := []string{}
 	if !isRoot {
-		isCollapsed := collapsedPaths.IsCollapsed(node.GetPath())
+		isCollapsed := collapsedPaths.IsCollapsed(node.GetInternalPath())
 		arr = append(arr, renderLine(node, treeDepth, visualDepth, isCollapsed))
 	}
 
-	if collapsedPaths.IsCollapsed(node.GetPath()) {
+	if collapsedPaths.IsCollapsed(node.GetInternalPath()) {
 		return arr
 	}
 
@@ -111,9 +115,11 @@ func getFileLine(
 	hasStagedChanges bool,
 	treeDepth int,
 	visualDepth int,
+	showNumstat,
 	showFileIcons bool,
 	submoduleConfigs []*models.SubmoduleConfig,
 	node *filetree.Node[models.File],
+	customIconsConfig *config.CustomIconsConfig,
 ) string {
 	name := fileNameAtDepth(node, treeDepth)
 	output := ""
@@ -154,8 +160,8 @@ func getFileLine(
 	isDirectory := file == nil
 
 	if showFileIcons {
-		icon := icons.IconForFile(name, isSubmodule, isLinkedWorktree, isDirectory)
-		paint := color.C256(icon.Color, false)
+		icon := icons.IconForFile(name, isSubmodule, isLinkedWorktree, isDirectory, customIconsConfig)
+		paint := color.HEX(icon.Color, false)
 		output += paint.Sprint(icon.Icon) + nameColor.Sprint(" ")
 	}
 
@@ -165,6 +171,12 @@ func getFileLine(
 		output += theme.DefaultTextColor.Sprint(" (submodule)")
 	}
 
+	if file != nil && showNumstat {
+		if lineChanges := formatLineChanges(file.LinesAdded, file.LinesDeleted); lineChanges != "" {
+			output += " " + lineChanges
+		}
+	}
+
 	return output
 }
 
@@ -186,6 +198,23 @@ func formatFileStatus(file *models.File, restColor style.TextStyle) string {
 	return firstCharCl.Sprint(firstChar) + secondCharCl.Sprint(secondChar)
 }
 
+func formatLineChanges(linesAdded, linesDeleted int) string {
+	output := ""
+
+	if linesAdded != 0 {
+		output += style.FgGreen.Sprintf("+%d", linesAdded)
+	}
+
+	if linesDeleted != 0 {
+		if output != "" {
+			output += " "
+		}
+		output += style.FgRed.Sprintf("-%d", linesDeleted)
+	}
+
+	return output
+}
+
 func getCommitFileLine(
 	isCollapsed bool,
 	treeDepth int,
@@ -193,6 +222,7 @@ func getCommitFileLine(
 	node *filetree.Node[models.CommitFile],
 	status patch.PatchStatus,
 	showFileIcons bool,
+	customIconsConfig *config.CustomIconsConfig,
 ) string {
 	indentation := strings.Repeat("  ", visualDepth)
 	name := commitFileNameAtDepth(node, treeDepth)
@@ -241,8 +271,8 @@ func getCommitFileLine(
 	isLinkedWorktree := false
 
 	if showFileIcons {
-		icon := icons.IconForFile(name, isSubmodule, isLinkedWorktree, isDirectory)
-		paint := color.C256(icon.Color, false)
+		icon := icons.IconForFile(name, isSubmodule, isLinkedWorktree, isDirectory, customIconsConfig)
+		paint := color.HEX(icon.Color, false)
 		output += paint.Sprint(icon.Icon) + " "
 	}
 
@@ -268,13 +298,19 @@ func getColorForChangeStatus(changeStatus string) style.TextStyle {
 }
 
 func fileNameAtDepth(node *filetree.Node[models.File], depth int) string {
-	splitName := split(node.Path)
+	splitName := split(node.GetInternalPath())
+	if depth == 0 && splitName[0] == "." {
+		if len(splitName) == 1 {
+			return "/"
+		}
+		depth = 1
+	}
 	name := join(splitName[depth:])
 
 	if node.File != nil && node.File.IsRename() {
-		splitPrevName := split(node.File.PreviousName)
+		splitPrevName := split("./" + node.File.PreviousPath)
 
-		prevName := node.File.PreviousName
+		prevName := node.File.PreviousPath
 		// if the file has just been renamed inside the same directory, we can shave off
 		// the prefix for the previous path too. Otherwise we'll keep it unchanged
 		sameParentDir := len(splitName) == len(splitPrevName) && join(splitName[0:depth]) == join(splitPrevName[0:depth])
@@ -289,7 +325,13 @@ func fileNameAtDepth(node *filetree.Node[models.File], depth int) string {
 }
 
 func commitFileNameAtDepth(node *filetree.Node[models.CommitFile], depth int) string {
-	splitName := split(node.Path)
+	splitName := split(node.GetInternalPath())
+	if depth == 0 && splitName[0] == "." {
+		if len(splitName) == 1 {
+			return "/"
+		}
+		depth = 1
+	}
 	name := join(splitName[depth:])
 
 	return name
