@@ -48,6 +48,9 @@ var DropTodoCommitWithUpdateRef = NewIntegrationTest(NewIntegrationTestArgs{
 				Contains("<-- YOU ARE HERE --- commit 02").IsSelected(),
 				Contains("CI commit 01"),
 			).
+			Tap(func() {
+				t.Views().Main().Content(Contains("commit 02"))
+			}).
 			NavigateToLine(Contains("commit 06")).
 			Press(keys.Universal.Remove)
 
