@@ -26,9 +26,11 @@ var MoveToIndex = NewIntegrationTest(NewIntegrationTestArgs{
 		t.Views().CommitFiles().
 			IsFocused().
 			Lines(
-				Contains("file1").IsSelected(),
+				Equals("▼ /").IsSelected(),
+				Contains("file1"),
 				Contains("file2"),
 			).
+			SelectNextItem().
 			PressPrimaryAction()
 
 		t.Views().Information().Content(Contains("Building patch"))
